"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var errors_1 = require("./errors");
var file_parser_1 = require("./parsers/file-parser");
var composer_parser_1 = require("./parsers/composer-parser");
function buildDepTree(lockFileContent, manifestFileContent, defaultProjectName, systemVersions) {
    var lockFileJson = file_parser_1.FileParser.parseLockFile(lockFileContent);
    var manifestJson = file_parser_1.FileParser.parseManifestFile(manifestFileContent);
    if (!lockFileJson.packages) {
        throw new errors_1.InvalidUserInputError('Invalid lock file. Must contain `packages` property');
    }
    var applicationName = manifestJson.name || defaultProjectName;
    var applicationVersion = composer_parser_1.ComposerParser.getVersion(manifestJson) || '0.0.0';
    return {
        name: applicationName,
        version: applicationVersion,
        packageFormatVersion: 'composer:0.0.1',
        dependencies: composer_parser_1.ComposerParser.buildDependencies(manifestJson, lockFileJson.packages, manifestJson, [applicationName + "@" + applicationVersion], systemVersions),
    };
}
exports.buildDepTree = buildDepTree;
function buildDepTreeFromFiles(basePath, lockFileName, systemVersions) {
    if (!basePath) {
        throw new errors_1.InvalidUserInputError('Missing `basePath` parameter for buildDepTreeFromFiles()');
    }
    if (!lockFileName) {
        throw new errors_1.InvalidUserInputError('Missing `lockfile` parameter for buildDepTreeFromFiles()');
    }
    if (!systemVersions) {
        throw new errors_1.InvalidUserInputError('Missing `systemVersions` parameter for buildDepTreeFromFiles()');
    }
    var lockFilePath = path.resolve(basePath, lockFileName);
    var manifestFilePath = path.resolve(basePath, path.dirname(lockFilePath), 'composer.json');
    if (!fs.existsSync(lockFilePath)) {
        throw new errors_1.InvalidUserInputError("Lockfile not found at location: " + lockFilePath);
    }
    if (!fs.existsSync(manifestFilePath)) {
        throw new errors_1.InvalidUserInputError("Target file composer.json not found at location: " + manifestFilePath);
    }
    var lockFileContent = fs.readFileSync(lockFilePath, 'utf-8');
    var manifestFileContent = fs.readFileSync(manifestFilePath, 'utf-8');
    var defaultProjectName = getDefaultProjectName(basePath, lockFileName);
    return buildDepTree(lockFileContent, manifestFileContent, defaultProjectName, systemVersions);
}
exports.buildDepTreeFromFiles = buildDepTreeFromFiles;
function getDefaultProjectName(basePath, lockFileName) {
    return path.dirname(path.resolve(path.join(basePath, lockFileName))).split(path.sep).pop();
}
//# sourceMappingURL=index.js.map